/***************************************************************************
 *   Copyright (C) 2007-2010 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef VISUALMENU_H
#define VISUALMENU_H

#include <QMenu>
#include <QAction>

class VisualFactory;

/**
    @author Ilya Kotov <forkotov02@hotmail.ru>
*/
class VisualMenu : public QMenu
{
    Q_OBJECT
public:
    VisualMenu(QWidget *parent = 0);

    ~VisualMenu();

public slots:
    void updateActions();
};

class VisualAction : public QAction
{
    Q_OBJECT
public:
    VisualAction(VisualFactory *factory, QWidget *parent = 0);

private slots:
    void select(bool);

private:
    VisualFactory *m_factory;

};

#endif
